; The CMD file of Haohmaru.
; File Version: 00.03.12
; Created by SuperScott
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
[Command]
name = "BFD_ax"
command = ~B, F, DF, D, a+x

;-| Special Motions |------------------------------------------------------
[Command]
name = "FDF_x"
command = ~F, D, DF, x

[Command]
name = "FDF_y"
command = ~F, D, DF, y

[Command]
name = "FDF_a"
command = ~F, D, DF, a

[Command]
name = "FDF_b"
command = ~F, D, DF, b

[Command]
name = "BDB_x"
command = ~B, D, DB, x

[Command]
name = "BDB_a"
command = ~B, D, DB, a

[Command]
name = "BDB_b"
command = ~B, D, DB, b

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "ax"
command = a+x
time = 1

[Command]
name = "by"
command = b+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "downfwd_a"
command = /DF,a
time = 1

[Command]
name = "downfwd_b"
command = /DF,b
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ax"
command = /F, a+x
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Master Art
[State -1]
type = ChangeState
value = 3000
triggerall = command = "BFD_ax"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = statetype != A
trigger3 = hitdefattr = SC, NA, SA
trigger3 = movecontact = 1


;===========================================================================
;---------------------------------------------------------------------------
; Crash
[State -1]
type = ChangeState
value = 1400
triggerall = command = "FDF_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 210
trigger4 = stateno = 310
trigger5 = stateno = 200
trigger6 = stateno = 300
trigger7 = stateno = 3511

;---------------------------------------------------------------------------
; Sand
[State -1]
type = ChangeState
value = 1300
triggerall = command = "QCF_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 200
trigger4 = stateno = 300
trigger5 = stateno = 400
trigger6 = stateno = 500
trigger7 = stateno = 210
trigger8 = stateno = 310
trigger9 = stateno = 3511

;---------------------------------------------------------------------------
;U-CUT
[State -1]
type = ChangeState
value = 1200
triggerall = command = "BDB_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 200
trigger4 = stateno = 300
trigger5 = stateno = 400
trigger6 = stateno = 500
trigger7 = stateno = 210
trigger8 = stateno = 310
trigger9 = stateno = 3511

[State -1]
type = ChangeState
value = 1210
triggerall = command = "BDB_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 200
trigger4 = stateno = 300
trigger5 = stateno = 400
trigger6 = stateno = 500
trigger7 = stateno = 210
trigger8 = stateno = 310
trigger9 = stateno = 3511

[State -1]
type = ChangeState
value = 1220
triggerall = command = "BDB_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 200
trigger4 = stateno = 300
trigger5 = stateno = 400
trigger6 = stateno = 500
trigger7 = stateno = 210
trigger8 = stateno = 310
trigger9 = stateno = 3511



;---------------------------------------------------------------------------
;U-CUT
[State -1]
type = ChangeState
value = 1100
triggerall = command = "FDF_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 200
trigger4 = stateno = 300
trigger5 = stateno = 400
trigger6 = stateno = 500
trigger7 = stateno = 210
trigger8 = stateno = 310
trigger9 = stateno = 3511

[State -1]
type = ChangeState
value = 1110
triggerall = command = "FDF_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 200
trigger4 = stateno = 300
trigger5 = stateno = 400
trigger6 = stateno = 500
trigger7 = stateno = 210
trigger8 = stateno = 310
trigger9 = stateno = 3511

[State -1]
type = ChangeState
value = 1120
triggerall = command = "FDF_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1
trigger3 = stateno = 200
trigger4 = stateno = 300
trigger5 = stateno = 400
trigger6 = stateno = 500
trigger7 = stateno = 210
trigger8 = stateno = 310
trigger9 = stateno = 3511

;---------------------------------------------------------------------------
;TWIST
[State -1]
type = ChangeState
value = 1000
triggerall = command = "QCF_x"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger3 = stateno = 300
trigger4 = stateno = 400
trigger5 = stateno = 500
trigger6 = stateno = 210
trigger7 = stateno = 310
trigger8 = stateno = 3511

[State -1]
type = ChangeState
value = 1010
triggerall = command = "QCF_a"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger3 = stateno = 300
trigger4 = stateno = 400
trigger5 = stateno = 500
trigger6 = stateno = 210
trigger7 = stateno = 310
trigger8 = stateno = 3511

[State -1]
type = ChangeState
value = 1020
triggerall = command = "QCF_b"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger3 = stateno = 300
trigger4 = stateno = 400
trigger5 = stateno = 500
trigger6 = stateno = 210
trigger7 = stateno = 310
trigger8 = stateno = 3511

;---------------------------------------------------------------------------
; Master Art 2
[State -1]
type = ChangeState
value = 3500
triggerall = command = "by"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = C
trigger2 = ctrl = 1

[State -1]
type = ChangeState
value = 3501
triggerall = command = "fwd_x"
trigger1 = stateno = 3500
trigger1 = movehit = 1
trigger1 = anim != 3500

[State -1]
type = ChangeState
value = 3502
triggerall = command = "x"
trigger1 = stateno = 3501
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3503
triggerall = command = "a"
trigger1 = stateno = 3502
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3504
triggerall = command = "a"
trigger1 = stateno = 3503
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3505
triggerall = command = "b"
trigger1 = stateno = 3504
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3506
triggerall = command = "b"
trigger1 = stateno = 3505
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3507
trigger1 = command = "x"
trigger1 = stateno = 3506
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3508
trigger1 = command = "a"
trigger1 = stateno = 3507
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3509
trigger1 = command = "b"
trigger1 = stateno = 3508
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3510
trigger1 = command = "b"
trigger1 = AnimElem = 6, >= 0
trigger1 = stateno = 3509
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3511
trigger1 = command = "b"
trigger1 = AnimElem = 5, >= 0
trigger1 = stateno = 3510
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3512
trigger1 = command = "b"
trigger1 = stateno = 3511
trigger1 = movehit = 1
trigger1 = AnimElem = 5, >= 0

[State -1]
type = ChangeState
value = 3513
trigger1 = command = "b"
trigger1 = stateno = 3512
trigger1 = movehit = 1
trigger1 = AnimElem = 4, >= 0

;---------------------------------------------------------------------------
; LEN 1
[State -1]
type = ChangeState
value = 3601
trigger1 = command = "a"
trigger1 = stateno = 3500
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3602
trigger1 = command = "a"
trigger1 = stateno = 3601
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3603
trigger1 = command = "b"
trigger1 = stateno = 3602
trigger1 = movehit = 1

;---------------------------------------------------------------------------
; LEN 2
[State -1]
type = ChangeState
value = 3701
trigger1 = command = "x"
trigger1 = stateno = 3500
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3702
trigger1 = command = "x"
trigger1 = stateno = 3701
trigger1 = movehit = 1

[State -1]
type = ChangeState
value = 3703
trigger1 = command = "x"
trigger1 = stateno = 3702
trigger1 = movehit = 1
trigger2 = command = "a"
trigger2 = stateno = 3702
trigger2 = movehit = 1


;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 900
trigger1 = command = "fwd_ax"
trigger1 = statetype = S
trigger1 = p2bodydist X < 60
trigger1 = p2statetype = S
trigger1 = ctrl = 1
trigger1 = stateno != 100
;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Hide
[State -1]
type = ChangeState
value = 380
trigger1 = command = "ax"
trigger1 = statetype = S
trigger1 = stateno != 100
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Punch
[State -1]
type = ChangeState
value = 370
trigger1 = command = "ab"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (front)
[State -1]
type = ChangeState
value = 950
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "fwd_b";Near, p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2bodydist X < 7
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_b";Near, p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2bodydist X < 7
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
;Stand_Throw (Back)
[State -1]
type = ChangeState
value = 955
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "back_b";Near, p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2bodydist X < 10
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "back_b";Near, p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2bodydist X < 10
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;
;;---------------------------------------------------------------------------
;;Air_Throw1
;[State -1]
;type = ChangeState
;value = 950
;triggerall = statetype = A
;triggerall = ctrl = 1
;trigger1 = command = "fwd_ab"
;trigger2 = command = "back_ab"
;;---------------------------
;;Air_Throw1 (second set of commands)
;[State -1]
;type = ChangeState
;value = 950
;triggerall = statetype = A
;triggerall = ctrl = 1
;triggerall = p2bodydist X < 9
;triggerall = p2bodydist Y > -22
;triggerall = p2bodydist Y < 22
;triggerall = p2statetype = A
;triggerall = p2movetype != H
;trigger1 = command = "fwd_b"
;trigger2 = command = "back_b"
;
;
;===========================================================================
;---------------------------------------------------------------------------
;RUNNING_X
[State -1]
type = ChangeState
value = 340
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = stateno = 100
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RUNNING_B
[State -1]
type = ChangeState
value = 350
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = stateno = 100
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;running_Y
[State -1]
type = ChangeState
value = 360
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = stateno = 100
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;forward_Y
[State -1]
type = ChangeState
value = 330
triggerall = command = "fwd_y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_X CLOSE
[State -1]
type = ChangeState
value = 300
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = p2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_A CLOSE
[State -1]
type = ChangeState
value = 310
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = p2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 100
trigger2 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_B CLOSE
[State -1]
type = ChangeState
value = 320
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = p2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_X
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 210
triggerall = command != "holddown"
trigger1 = command = "a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = command = "b"
trigger2 = stateno = 320
trigger2 = movehit = 1
trigger2 = time > 20

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 220
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Y
[State -1]
type = ChangeState
value = 230
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_X Close
[State -1]
type = ChangeState
value = 500
triggerall = command = "holddown"
triggerall = p2bodydist X < 30
trigger1 = command = "a"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = command = "x"
trigger2 = statetype = C
trigger2 = ctrl = 1


;---------------------------------------------------------------------------
;Crouch_X
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = p2bodydist X >= 30
trigger1 = statetype = C
trigger1 = ctrl = 1

[State -1]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = p2bodydist X >= 30
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 420
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 600
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "a"
trigger2 = statetype = A
trigger2 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 620
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
